@@ -5,8 +5,9 @@ from .options_validator import OptionsValidator
 from .regex_validator import RegexValidator
 from .type_validator import TypeValidator
 from .string_validator import StrValidator
+from .uuid_validator import UUIDValidator
 
-__version__ = '0.1.2'
+__version__ = '0.1.5'
 
 __all__ = [
     "CPFValidator",
@@ -16,5 +17,6 @@ __all__ = [
     "RegexValidator",
     "TypeValidator",
     "StrValidator",
+    "UUIDValidator",
     "__version__",
 ]
